@@ -3,7 +3,7 @@ R_VERSION_MAX <- IS_USER <- IS_END_OF_LIFE <- IS_UPGRADEABLE <- UPGRADE_IS_DEVEL
   NEXT_R_DEVEL_VERSION <- NULL
 
 ## The following values are updated with each Bioc release; see .onLoad
-BIOC_VERSION <- package_version("3.3")     # Bioc version for this package
+BIOC_VERSION <- package_version("3.4")     # Bioc version for this package
 # R_VERSION_MAX <- package_version("3.3.0")  # Maximum version of R for
 #                                            # this version of BiocInstaller
 # IS_USER <- FALSE                           # TRUE if this version of
@@ -107,6 +107,10 @@ globalVariables("repos")           # used in 'bootstrap' functions
          if (IS_UPGRADEABLE)
              .message("A newer version of Bioconductor is available for
                        this version of R, ?BiocUpgrade for help")
+         else if (Rversion > R_VERSION_MAX)
+             .warning("Bioconductor version %s is too old for R version %s;
+                 see https://bioconductor.org/install/#troubleshoot-biocinstaller",
+                 BIOC_VERSION, Rversion)
          else
              .message("A new version of Bioconductor is available after
                        installing the most recent version of R; see
@@ -115,10 +119,9 @@ globalVariables("repos")           # used in 'bootstrap' functions
          if (Rversion >= NEXT_R_DEVEL_VERSION)
              .message("Bioconductor does not yet support R version %s", Rversion)
          else
-             .warning("BiocInstaller version %s is too old for R version %s;
-                       remove.packages(\"BiocInstaller\"), re-start R, then
-                       source(\"%s//bioconductor.org/biocLite.R\")",
-                      BIOC_VERSION, Rversion, .protocol())
+             .warning("Bioconductor version %s is too old for R version %s;
+                 see https://bioconductor.org/install/#troubleshoot-biocinstaller",
+                 BIOC_VERSION, Rversion)
      }
 
 }
